==> blancoMessage-0.5.6-src.zip: blancoMessage/blanco.js/main/blanco/message/message/BlancoMessageMessage.js <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 */

/**
 * ftHgRXgN^
 * @fileoverview ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * @class blancoMessageIɗp郁bZ[WNXłB
 * @constructor
 */
function BlancoMessageMessage() {
    /* p[^̐A^`FbNs܂B */
    if (arguments.length !== 0) {
        throw new Error("[ArgumentException]: BlancoMessageMessage.BlancoMessageMessage ̃p[^[0]łKv܂Bۂɂ[" + arguments.length +  "]̃p[^𔺂ČĂяo܂B");
    }

}

/**
 * [bZ[W`ID[{0}]̃pbP[Ww肳Ă܂B]
 * @type string
 * No.2:
 */
BlancoMessageMessage.MBMSGI01 = "[MBMSGI01] bZ[W`ID[{0}]̃pbP[Ww肳Ă܂B";

/**
 * [T|[gȂo̓vO~Oꏈn[{0}]w肳܂B]
 * @type string
 * No.3:
 */
BlancoMessageMessage.MBMSGI02 = "[MBMSGI02] T|[gȂo̓vO~Oꏈn[{0}]w肳܂B";

/**
 * [bZ[W`ID[{0}]ɂāAL[[{1}]2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B]
 * @type string
 * No.4:
 */
BlancoMessageMessage.MBMSGI03 = "[MBMSGI03] bZ[W`ID[{0}]ɂāAL[[{1}]2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B";

/**
 * [bZ[W`ID[{0}]ɂāAL[[{1}]̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[{2}]ƃ\[XohƂĔfꍇ̒ǔ[{3}]ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB]
 * @type string
 * No.5:
 */
BlancoMessageMessage.MBMSGI04 = "[MBMSGI04] bZ[W`ID[{0}]ɂāAL[[{1}]̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[{2}]ƃ\[XohƂĔfꍇ̒ǔ[{3}]ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB";

/**
 * [^fBNg[{0}]݂܂B]
 * @type string
 * No.8:
 */
BlancoMessageMessage.MBMSGA01 = "[MBMSGA01] ^fBNg[{0}]݂܂B";

/**
 * bZ[W`ID[BlancoMessage]AL[[MBMSGI01]̕擾܂B
 * @addon
 * @param {string} arg0 u{0}̒lB
 * @return bZ[WB
 * @type string
 * No.2:
 * [bZ[W`ID[{0}]̃pbP[Ww肳Ă܂B]
 */
BlancoMessageMessage.prototype.getMbmsgi01 = function(/* string */ arg0) {
    /* p[^̐A^`FbNs܂B */
    if (arguments.length !== 1) {
        throw new Error("[ArgumentException]: BlancoMessageMessage.getMbmsgi01 ̃p[^[1]łKv܂Bۂɂ[" + arguments.length +  "]̃p[^𔺂ČĂяo܂B");
    }
    if (typeof(arg0) != "string") {
        throw new Error("[ArgumentException]: BlancoMessageMessage.getMbmsgi01 1Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[" + typeof(arg0) + "]^^܂B");
    }

    return "[MBMSGI01] bZ[W`ID[" + arg0 + "]̃pbP[Ww肳Ă܂B";
};

/**
 * bZ[W`ID[BlancoMessage]AL[[MBMSGI02]̕擾܂B
 * @addon
 * @param {string} arg0 u{0}̒lB
 * @return bZ[WB
 * @type string
 * No.3:
 * [T|[gȂo̓vO~Oꏈn[{0}]w肳܂B]
 */
BlancoMessageMessage.prototype.getMbmsgi02 = function(/* string */ arg0) {
    /* p[^̐A^`FbNs܂B */
    if (arguments.length !== 1) {
        throw new Error("[ArgumentException]: BlancoMessageMessage.getMbmsgi02 ̃p[^[1]łKv܂Bۂɂ[" + arguments.length +  "]̃p[^𔺂ČĂяo܂B");
    }
    if (typeof(arg0) != "string") {
        throw new Error("[ArgumentException]: BlancoMessageMessage.getMbmsgi02 1Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[" + typeof(arg0) + "]^^܂B");
    }

    return "[MBMSGI02] T|[gȂo̓vO~Oꏈn[" + arg0 + "]w肳܂B";
};

/**
 * bZ[W`ID[BlancoMessage]AL[[MBMSGI03]̕擾܂B
 * @addon
 * @param {string} arg0 u{0}̒lB
 * @param {string} arg1 u{1}̒lB
 * @return bZ[WB
 * @type string
 * No.4:
 * [bZ[W`ID[{0}]ɂāAL[[{1}]2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B]
 */
BlancoMessageMessage.prototype.getMbmsgi03 = function(/* string */ arg0, /* string */ arg1) {
    /* p[^̐A^`FbNs܂B */
    if (arguments.length !== 2) {
        throw new Error("[ArgumentException]: BlancoMessageMessage.getMbmsgi03 ̃p[^[2]łKv܂Bۂɂ[" + arguments.length +  "]̃p[^𔺂ČĂяo܂B");
    }
    if (typeof(arg0) != "string") {
        throw new Error("[ArgumentException]: BlancoMessageMessage.getMbmsgi03 1Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[" + typeof(arg0) + "]^^܂B");
    }
    if (typeof(arg1) != "string") {
        throw new Error("[ArgumentException]: BlancoMessageMessage.getMbmsgi03 2Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[" + typeof(arg1) + "]^^܂B");
    }

    return "[MBMSGI03] bZ[W`ID[" + arg0 + "]ɂāAL[[" + arg1 + "]2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B";
};

/**
 * bZ[W`ID[BlancoMessage]AL[[MBMSGI04]̕擾܂B
 * @addon
 * @param {string} arg0 u{0}̒lB
 * @param {string} arg1 u{1}̒lB
 * @param {string} arg2 u{2}̒lB
 * @param {string} arg3 u{3}̒lB
 * @return bZ[WB
 * @type string
 * No.5:
 * [bZ[W`ID[{0}]ɂāAL[[{1}]̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[{2}]ƃ\[XohƂĔfꍇ̒ǔ[{3}]ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB]
 */
BlancoMessageMessage.prototype.getMbmsgi04 = function(/* string */ arg0, /* string */ arg1, /* string */ arg2, /* string */ arg3) {
    /* p[^̐A^`FbNs܂B */
    if (arguments.length !== 4) {
        throw new Error("[ArgumentException]: BlancoMessageMessage.getMbmsgi04 ̃p[^[4]łKv܂Bۂɂ[" + arguments.length +  "]̃p[^𔺂ČĂяo܂B");
    }
    if (typeof(arg0) != "string") {
        throw new Error("[ArgumentException]: BlancoMessageMessage.getMbmsgi04 1Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[" + typeof(arg0) + "]^^܂B");
    }
    if (typeof(arg1) != "string") {
        throw new Error("[ArgumentException]: BlancoMessageMessage.getMbmsgi04 2Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[" + typeof(arg1) + "]^^܂B");
    }
    if (typeof(arg2) != "string") {
        throw new Error("[ArgumentException]: BlancoMessageMessage.getMbmsgi04 3Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[" + typeof(arg2) + "]^^܂B");
    }
    if (typeof(arg3) != "string") {
        throw new Error("[ArgumentException]: BlancoMessageMessage.getMbmsgi04 4Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[" + typeof(arg3) + "]^^܂B");
    }

    return "[MBMSGI04] bZ[W`ID[" + arg0 + "]ɂāAL[[" + arg1 + "]̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[" + arg2 + "]ƃ\[XohƂĔfꍇ̒ǔ[" + arg3 + "]ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB";
};

/**
 * bZ[W`ID[BlancoMessage]AL[[MBMSGA01]̕擾܂B
 * @addon
 * @param {string} arg0 u{0}̒lB
 * @return bZ[WB
 * @type string
 * No.8:
 * [^fBNg[{0}]݂܂B]
 */
BlancoMessageMessage.prototype.getMbmsga01 = function(/* string */ arg0) {
    /* p[^̐A^`FbNs܂B */
    if (arguments.length !== 1) {
        throw new Error("[ArgumentException]: BlancoMessageMessage.getMbmsga01 ̃p[^[1]łKv܂Bۂɂ[" + arguments.length +  "]̃p[^𔺂ČĂяo܂B");
    }
    if (typeof(arg0) != "string") {
        throw new Error("[ArgumentException]: BlancoMessageMessage.getMbmsga01 1Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[" + typeof(arg0) + "]^^܂B");
    }

    return "[MBMSGA01] ^fBNg[" + arg0 + "]݂܂B";
};
/* NX[BlancoMessageMessage]錾̏IB */

==> blancoMessage-0.5.7-src.zip: blancoMessage/blanco.js/main/blanco/message/message/BlancoMessageMessage.js <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 */

/**
 * ftHgRXgN^
 * @fileoverview ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * @class blancoMessageIɗp郁bZ[WNXłB
 * @constructor
 */
function BlancoMessageMessage() {
    /* p[^̐A^`FbNs܂B */
    if (arguments.length !== 0) {
        throw new Error("[ArgumentException]: BlancoMessageMessage.BlancoMessageMessage ̃p[^[0]łKv܂Bۂɂ[" + arguments.length +  "]̃p[^𔺂ČĂяo܂B");
    }

}

/**
 * [bZ[W`ID[{0}]̃pbP[Ww肳Ă܂B]
 * @type string
 * No.2:
 */
BlancoMessageMessage.MBMSGI01 = "[MBMSGI01] bZ[W`ID[{0}]̃pbP[Ww肳Ă܂B";

/**
 * L[l: KEY_MBMSGI01
 * @type string
 * No.2:
 */
BlancoMessageMessage.KEY_MBMSGI01 = "MBMSGI01";

/**
 * [T|[gȂo̓vO~Oꏈn[{0}]w肳܂B]
 * @type string
 * No.3:
 */
BlancoMessageMessage.MBMSGI02 = "[MBMSGI02] T|[gȂo̓vO~Oꏈn[{0}]w肳܂B";

/**
 * L[l: KEY_MBMSGI02
 * @type string
 * No.3:
 */
BlancoMessageMessage.KEY_MBMSGI02 = "MBMSGI02";

/**
 * [bZ[W`ID[{0}]ɂāAL[[{1}]2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B]
 * @type string
 * No.4:
 */
BlancoMessageMessage.MBMSGI03 = "[MBMSGI03] bZ[W`ID[{0}]ɂāAL[[{1}]2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B";

/**
 * L[l: KEY_MBMSGI03
 * @type string
 * No.4:
 */
BlancoMessageMessage.KEY_MBMSGI03 = "MBMSGI03";

/**
 * [bZ[W`ID[{0}]ɂāAL[[{1}]̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[{2}]ƃ\[XohƂĔfꍇ̒ǔ[{3}]ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB]
 * @type string
 * No.5:
 */
BlancoMessageMessage.MBMSGI04 = "[MBMSGI04] bZ[W`ID[{0}]ɂāAL[[{1}]̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[{2}]ƃ\[XohƂĔfꍇ̒ǔ[{3}]ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB";

/**
 * L[l: KEY_MBMSGI04
 * @type string
 * No.5:
 */
BlancoMessageMessage.KEY_MBMSGI04 = "MBMSGI04";

/**
 * [^fBNg[{0}]݂܂B]
 * @type string
 * No.8:
 */
BlancoMessageMessage.MBMSGA01 = "[MBMSGA01] ^fBNg[{0}]݂܂B";

/**
 * L[l: KEY_MBMSGA01
 * @type string
 * No.8:
 */
BlancoMessageMessage.KEY_MBMSGA01 = "MBMSGA01";

/**
 * bZ[W`ID[BlancoMessage]AL[[MBMSGI01]̕擾܂B
 * @addon
 * @param {string} arg0 u{0}̒lB
 * @return bZ[WB
 * @type string
 * No.2:
 * [bZ[W`ID[{0}]̃pbP[Ww肳Ă܂B]
 */
BlancoMessageMessage.prototype.getMbmsgi01 = function(/* string */ arg0) {
    /* p[^̐A^`FbNs܂B */
    if (arguments.length !== 1) {
        throw new Error("[ArgumentException]: BlancoMessageMessage.getMbmsgi01 ̃p[^[1]łKv܂Bۂɂ[" + arguments.length +  "]̃p[^𔺂ČĂяo܂B");
    }
    if (typeof(arg0) != "string") {
        throw new Error("[ArgumentException]: BlancoMessageMessage.getMbmsgi01 1Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[" + typeof(arg0) + "]^^܂B");
    }

    return "[MBMSGI01] bZ[W`ID[" + arg0 + "]̃pbP[Ww肳Ă܂B";
};

/**
 * bZ[W`ID[BlancoMessage]AL[[MBMSGI02]̕擾܂B
 * @addon
 * @param {string} arg0 u{0}̒lB
 * @return bZ[WB
 * @type string
 * No.3:
 * [T|[gȂo̓vO~Oꏈn[{0}]w肳܂B]
 */
BlancoMessageMessage.prototype.getMbmsgi02 = function(/* string */ arg0) {
    /* p[^̐A^`FbNs܂B */
    if (arguments.length !== 1) {
        throw new Error("[ArgumentException]: BlancoMessageMessage.getMbmsgi02 ̃p[^[1]łKv܂Bۂɂ[" + arguments.length +  "]̃p[^𔺂ČĂяo܂B");
    }
    if (typeof(arg0) != "string") {
        throw new Error("[ArgumentException]: BlancoMessageMessage.getMbmsgi02 1Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[" + typeof(arg0) + "]^^܂B");
    }

    return "[MBMSGI02] T|[gȂo̓vO~Oꏈn[" + arg0 + "]w肳܂B";
};

/**
 * bZ[W`ID[BlancoMessage]AL[[MBMSGI03]̕擾܂B
 * @addon
 * @param {string} arg0 u{0}̒lB
 * @param {string} arg1 u{1}̒lB
 * @return bZ[WB
 * @type string
 * No.4:
 * [bZ[W`ID[{0}]ɂāAL[[{1}]2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B]
 */
BlancoMessageMessage.prototype.getMbmsgi03 = function(/* string */ arg0, /* string */ arg1) {
    /* p[^̐A^`FbNs܂B */
    if (arguments.length !== 2) {
        throw new Error("[ArgumentException]: BlancoMessageMessage.getMbmsgi03 ̃p[^[2]łKv܂Bۂɂ[" + arguments.length +  "]̃p[^𔺂ČĂяo܂B");
    }
    if (typeof(arg0) != "string") {
        throw new Error("[ArgumentException]: BlancoMessageMessage.getMbmsgi03 1Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[" + typeof(arg0) + "]^^܂B");
    }
    if (typeof(arg1) != "string") {
        throw new Error("[ArgumentException]: BlancoMessageMessage.getMbmsgi03 2Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[" + typeof(arg1) + "]^^܂B");
    }

    return "[MBMSGI03] bZ[W`ID[" + arg0 + "]ɂāAL[[" + arg1 + "]2ȏ゠܂BL[2ȏw肷邱Ƃ͂ł܂B";
};

/**
 * bZ[W`ID[BlancoMessage]AL[[MBMSGI04]̕擾܂B
 * @addon
 * @param {string} arg0 u{0}̒lB
 * @param {string} arg1 u{1}̒lB
 * @param {string} arg2 u{2}̒lB
 * @param {string} arg3 u{3}̒lB
 * @return bZ[WB
 * @type string
 * No.5:
 * [bZ[W`ID[{0}]ɂāAL[[{1}]̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[{2}]ƃ\[XohƂĔfꍇ̒ǔ[{3}]ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB]
 */
BlancoMessageMessage.prototype.getMbmsgi04 = function(/* string */ arg0, /* string */ arg1, /* string */ arg2, /* string */ arg3) {
    /* p[^̐A^`FbNs܂B */
    if (arguments.length !== 4) {
        throw new Error("[ArgumentException]: BlancoMessageMessage.getMbmsgi04 ̃p[^[4]łKv܂Bۂɂ[" + arguments.length +  "]̃p[^𔺂ČĂяo܂B");
    }
    if (typeof(arg0) != "string") {
        throw new Error("[ArgumentException]: BlancoMessageMessage.getMbmsgi04 1Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[" + typeof(arg0) + "]^^܂B");
    }
    if (typeof(arg1) != "string") {
        throw new Error("[ArgumentException]: BlancoMessageMessage.getMbmsgi04 2Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[" + typeof(arg1) + "]^^܂B");
    }
    if (typeof(arg2) != "string") {
        throw new Error("[ArgumentException]: BlancoMessageMessage.getMbmsgi04 3Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[" + typeof(arg2) + "]^^܂B");
    }
    if (typeof(arg3) != "string") {
        throw new Error("[ArgumentException]: BlancoMessageMessage.getMbmsgi04 4Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[" + typeof(arg3) + "]^^܂B");
    }

    return "[MBMSGI04] bZ[W`ID[" + arg0 + "]ɂāAL[[" + arg1 + "]̃bZ[WsłBbZ[W`ƂĔfꍇ̒ǔ[" + arg2 + "]ƃ\[XohƂĔfꍇ̒ǔ[" + arg3 + "]ƂقȂ܂Bu̔ԍ͔ł܂Ă܂񂩁HtH[}bg`ĂB";
};

/**
 * bZ[W`ID[BlancoMessage]AL[[MBMSGA01]̕擾܂B
 * @addon
 * @param {string} arg0 u{0}̒lB
 * @return bZ[WB
 * @type string
 * No.8:
 * [^fBNg[{0}]݂܂B]
 */
BlancoMessageMessage.prototype.getMbmsga01 = function(/* string */ arg0) {
    /* p[^̐A^`FbNs܂B */
    if (arguments.length !== 1) {
        throw new Error("[ArgumentException]: BlancoMessageMessage.getMbmsga01 ̃p[^[1]łKv܂Bۂɂ[" + arguments.length +  "]̃p[^𔺂ČĂяo܂B");
    }
    if (typeof(arg0) != "string") {
        throw new Error("[ArgumentException]: BlancoMessageMessage.getMbmsga01 1Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[" + typeof(arg0) + "]^^܂B");
    }

    return "[MBMSGA01] ^fBNg[" + arg0 + "]݂܂B";
};
/* NX[BlancoMessageMessage]錾̏IB */
